summaryrefslogtreecommitdiffstats
path: root/juk/playlist.h
diff options
context:
space:
mode:
Diffstat (limited to 'juk/playlist.h')
-rw-r--r--juk/playlist.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/juk/playlist.h b/juk/playlist.h
index ba1363a1..22c16b45 100644
--- a/juk/playlist.h
+++ b/juk/playlist.h
@@ -420,7 +420,7 @@ protected:
virtual bool eventFilter(TQObject *watched, TQEvent *e);
virtual void keyPressEvent(TQKeyEvent *e);
- virtual TQDragObject *dragObject(TQWidget *tqparent);
+ virtual TQDragObject *dragObject(TQWidget *parent);
virtual TQDragObject *dragObject() { return dragObject(this); }
virtual bool canDecode(TQMimeSource *s);
virtual void decode(TQMimeSource *s, PlaylistItem *item = 0);
@@ -457,7 +457,7 @@ protected:
void setupItem(PlaylistItem *item);
/**
* Forwards the call to the tqparent to enable or disable automatic deletion
* of tree view playlists. Used by CollectionListItem.
*/
void setDynamicListsFrozen(bool frozen);
@@ -457,7 +457,7 @@ protected:
void setupItem(PlaylistItem *item);
/**
- * Forwards the call to the tqparent to enable or disable automatic deletion
+ * Forwards the call to the parent to enable or disable automatic deletion
* of tree view playlists. Used by CollectionListItem.
*/